@@ -1,7 +1,7 @@
 package App::DateUtils;
 
-our $DATE = '2016-07-10'; # DATE
-our $VERSION = '0.10'; # VERSION
+our $DATE = '2017-01-09'; # DATE
+our $VERSION = '0.11'; # VERSION
 
 use 5.010001;
 use strict;
@@ -85,10 +85,10 @@ sub parse_date {
 
     my %mods; # val = 1 if installed
     if ($args{all_modules}) {
-        require Module::Path::More;
+        require Module::Installed::Tiny;
         for my $mod0 (@parse_date_modules) {
             (my $mod = $mod0) =~ s/\(.+//;
-            $mods{$mod0} = Module::Path::More::module_path(module => $mod) ?
+            $mods{$mod0} = Module::Installed::Tiny::module_installed($mod) ?
                 1:0;
         }
     } else {
@@ -137,7 +137,7 @@ sub parse_date {
             }
             if ($mod =~ /^DateTime::Format::Alami/) {
                 my $res;
-                eval { $parser->parse_datetime($date, {format=>'combined'}) };
+                eval { $res = $parser->parse_datetime($date, {format=>'combined'}) };
                 if ($@) {
                     $rec->{is_parseable} = 0;
                 } else {
@@ -281,10 +281,10 @@ sub parse_duration {
 
     my %mods; # val = 1 if installed
     if ($args{all_modules}) {
-        require Module::Path::More;
+        require Module::Installed::Tiny;
         for my $mod0 (@parse_duration_modules) {
             (my $mod = $mod0) =~ s/\(.+//;
-            $mods{$mod0} = Module::Path::More::module_path(module => $mod) ?
+            $mods{$mod0} = Module::Installed::Tiny::module_installed($mod) ?
                 1:0;
         }
     } else {
@@ -560,7 +560,7 @@ App::DateUtils - An assortment of date-/time-related CLI utilities
 
 =head1 VERSION
 
-This document describes version 0.10 of App::DateUtils (from Perl distribution App-DateUtils), released on 2016-07-10.
+This document describes version 0.11 of App::DateUtils (from Perl distribution App-DateUtils), released on 2017-01-09.
 
 =head1 SYNOPSIS
 
@@ -608,7 +608,7 @@ Examples:
 
 =item * Convert "today" to epoch:
 
- dateconv(date => "today"); # -> 1468108800
+ dateconv(date => "today"); # -> 1483920000
 
 =item * Convert epoch to ymd:
 
@@ -689,14 +689,14 @@ Result:
        module          => "DateTime::Format::Flexible",
        original        => "tomorrow",
        is_parseable    => 1,
-       as_epoch        => 1468195200,
-       as_datetime_obj => "2016-07-11T00:00:00",
+       as_epoch        => 1484006400,
+       as_datetime_obj => "2017-01-10T00:00:00",
      },
      {
        module       => "DateTime::Format::Flexible",
        original     => "foo",
        is_parseable => 0,
-       error_msg    => "Invalid date format: foo at /home/s1/perl5/perlbrew/perls/perl-5.22.2/lib/site_perl/5.22.2/Perinci/Access.pm line 81. ",
+       error_msg    => "Invalid date format: foo at /home/u1/perl5/perlbrew/perls/perl-5.24.0/lib/site_perl/5.24.0/Perinci/Access.pm line 81. ",
      },
    ],
    {
@@ -765,9 +765,9 @@ Result:
        module          => "DateTime::Format::Alami::EN",
        original        => "23 May",
        is_parseable    => 1,
-       as_epoch        => undef,
-       as_datetime_obj => "",
-       pattern         => undef,
+       as_epoch        => 1495497600,
+       as_datetime_obj => "2017-05-23T00:00:00",
+       pattern         => "p_dateymd",
      },
    ],
    {
@@ -858,9 +858,9 @@ Result:
        module          => "DateTime::Format::Alami::ID",
        original        => "23 Mei",
        is_parseable    => 1,
-       as_epoch        => undef,
-       as_datetime_obj => "",
-       pattern         => undef,
+       as_epoch        => 1495497600,
+       as_datetime_obj => "2017-05-23T00:00:00",
+       pattern         => "p_dateymd",
      },
    ],
    {
@@ -951,8 +951,8 @@ Result:
        module          => "DateTime::Format::Flexible",
        original        => "23rd Jun",
        is_parseable    => 1,
-       as_epoch        => 1466640000,
-       as_datetime_obj => "2016-06-23T00:00:00",
+       as_epoch        => 1498176000,
+       as_datetime_obj => "2017-06-23T00:00:00",
      },
    ],
    {
@@ -981,8 +981,8 @@ Result:
        module          => "DateTime::Format::Flexible(de)",
        original        => "23 Dez",
        is_parseable    => 1,
-       as_epoch        => 1482451200,
-       as_datetime_obj => "2016-12-23T00:00:00",
+       as_epoch        => 1513987200,
+       as_datetime_obj => "2017-12-23T00:00:00",
      },
    ],
    {
@@ -1011,7 +1011,7 @@ Result:
        module       => "DateTime::Format::Flexible",
        original     => "foo",
        is_parseable => 0,
-       error_msg    => "Invalid date format: foo at /home/s1/perl5/perlbrew/perls/perl-5.22.2/lib/site_perl/5.22.2/Perinci/Access.pm line 81. ",
+       error_msg    => "Invalid date format: foo at /home/u1/perl5/perlbrew/perls/perl-5.24.0/lib/site_perl/5.24.0/Perinci/Access.pm line 81. ",
      },
    ],
    {
@@ -1076,8 +1076,8 @@ Result:
        module          => "DateTime::Format::Natural",
        original        => "23rd Jun",
        is_parseable    => 1,
-       as_epoch        => 1466640000,
-       as_datetime_obj => "2016-06-23T00:00:00",
+       as_epoch        => 1498176000,
+       as_datetime_obj => "2017-06-23T00:00:00",
      },
    ],
    {
@@ -1383,8 +1383,8 @@ Result:
        is_parseable => 1,
        as_secs => 1209600,
        as_dtdur_obj => "P2W",
-       date2 => "2016-07-24T05:38:44",
-       date1 => "2016-07-10T05:38:44",
+       date2 => "2017-01-23T02:56:04",
+       date1 => "2017-01-09T02:56:04",
      },
    ],
    {
@@ -1413,10 +1413,10 @@ Result:
        module => "DateTime::Format::Natural",
        original => "from 23 Jun to 29 Jun",
        is_parseable => 1,
-       as_secs => 970724,
-       as_dtdur_obj => "P1W4DT5H38M44S",
-       date1 => "2016-07-10T05:38:44",
-       date2 => "2016-06-29T00:00:00",
+       as_secs => 14866436,
+       as_dtdur_obj => "P5M2W5DT21H3M56S",
+       date2 => "2017-06-29T00:00:00",
+       date1 => "2017-01-09T02:56:04",
      },
    ],
    {
@@ -1592,7 +1592,7 @@ feature.
 =head1 SEE ALSO
 
 
-L<dateparse>, The official CLI for DateTime::Format::Natural.
+L<dateparse>. The official CLI for DateTime::Format::Natural.
 
 L<App::datecalc>
 
@@ -1602,7 +1602,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
